# My Data Toolkit: DToolKit

[![PyPI Project Version](https://img.shields.io/pypi/v/my-data-toolkit.svg)](https://pypi.org/project/my-data-toolkit/)
[![PyPI Python Versions](https://img.shields.io/pypi/pyversions/my-data-toolkit)](https://pypi.org/project/my-data-toolkit/)
[![Test Status](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/test.yaml/badge.svg)](https://github.com/Zeroto521/my-data-toolkit/actions/workflows/test.yaml)
[![Coverage Status](https://codecov.io/gh/Zeroto521/my-data-toolkit/branch/main/graph/badge.svg)](https://codecov.io/gh/Zeroto521/my-data-toolkit)
[![Documentation Status](https://readthedocs.org/projects/my-data-toolkit/badge/?version=latest)](https://my-data-toolkit.readthedocs.io/en/latest/?badge=latest)

Face the engineering of data preprocessing.

See [documentation](https://my-data-toolkit.readthedocs.io/) for more information.
